@@ -7,9 +7,10 @@ if sys.version_info >= (3, 11):
 else:
     import tomli as tomllib
 
-from .model import Configuration
+
+from .model import MainProfile
 
 
-def create_from_toml(__s: str) -> Configuration:
+def create_from_toml(__s: str) -> MainProfile:
     dict_data = tomllib.loads(__s)
-    return from_dict(dict_data, Configuration)
+    return from_dict(dict_data, MainProfile)
